# Pavilion

We sometimes share the Software Gardening Almanack through events, blog posts, or other media which we want to share with you under this pavilion.

## Poster for CU Anschutz DBMI Retreat - August 2025

We created this poster to share the Almanack with audiences attending the [CU Anschutz DBMI](https://medschool.cuanschutz.edu/dbmi) 2025 retreat.

We also archived the work for reference here: https://doi.org/10.5281/zenodo.16943577

<iframe src="../_posters/2025/almanack-2025-poster.pdf" width="100%" height="600px"></iframe>

## BSSw Blog Post Introducing the Almanack - April 2025

This blog post through the [Better Scientific Software (BSSw) Blog](https://bssw.io/blog_posts) shared our initial findings and efforts to apply Software Gardening via the Almanack book and Python package.

Please use the following link to read the article: https://bssw.io/blog_posts/growing-resilient-scientific-software-ecosystems-introducing-the-software-gardening-almanack

We also archived the work for reference here: https://doi.org/10.5281/zenodo.15330727

## OSSci Monthly Call - January 2025

The [OpenSource.science (OSSci)](https://www.opensource.science/) [Map of Open Source (MOSS)](https://www.opensource.science/moss) interest group invited us to present on the Almanack on 1/13/2025.

Please see the [presentation recording](https://youtu.be/b0sZWTl5Fsg?si=xGxYFA8SfbV4wBYB&t=506) or <a>slides below<a href="../_static/OSSci Monthly Call Jan 2025 - Software_Gardening_Almanack.pdf"> as a reference to this presentation.

<iframe src="../_static/OSSci Monthly Call Jan 2025 - Software_Gardening_Almanack.pdf" width="100%" height="600px"></iframe>

## BSSw Blog Post on Software Gardening - August 2023

This blog post through the [Better Scientific Software (BSSw) Blog](https://bssw.io/blog_posts) shared our original vision and understanding of Software Gardening as an analogy for the development and stewardship of research software.

Please use the following link to read the article: https://bssw.io/blog_posts/long-term-software-gardening-strategies-for-cultivating-scientific-development-ecosystems

We also archived the work for reference here: https://doi.org/10.5281/zenodo.15330702
